package com.webonlineapp.hyjavaapexdemo.examplecharts;

import java.util.Arrays;
import java.util.Date;
import java.util.List;

import com.hyjavaapex.chart.Apexchart;
import com.hyjavaapex.model.apexcharts.ChartOptions;
import com.hyjavaapex.model.apexcharts.Series;
import com.hyjavaapex.model.apexcharts.annotations.Points;
import com.hyjavaapex.model.apexcharts.annotations.Xaxis;
import com.hyjavaapex.model.apexcharts.annotations.Yaxis;
import com.hyjavaapex.model.apexcharts.constants.AxisType;
import com.hyjavaapex.model.apexcharts.constants.ChartType;
import com.hyjavaapex.model.apexcharts.constants.Curve;
import com.hyjavaapex.model.apexcharts.constants.HorizontalAlign;
import com.hyjavaapex.model.common.Color;
import com.hyjavaapex.model.common.General;
import com.webonlineapp.hyjavaapexdemo.charts.DemoChartBase;

public class LineChartWithAnnotations extends DemoChartBase {
	private static final long serialVersionUID = 1L;

	public Apexchart configure() {
		Apexchart apexchart = new Apexchart();
		ChartOptions chartOptions = apexchart.getChartOptions();
		
		chartOptions.getChart().setHeight("100%").setType(ChartType.LINE).setId("areachart-2");
		
		Yaxis y = new Yaxis();
		y.setY(8200).setBorderColor(new Color("#00E396"))
			.getLabel().setBorderColor(new Color("#00E396")).setText("Support")
				.getStyle().setColor(new Color("#fff")).setBackground(new Color("#00E396"));
		chartOptions.getAnnotations().getYaxis().add(y);
		
		y = new Yaxis();
		y.setY(8600).setY2(9000)
			.setBorderColor(new Color("#000")).setFillColor(new Color("#FEB019")).setOpacity(0.2)
			.getLabel().setBorderColor(new Color("#333")).setText("Y-axis range")
				.getStyle().setFontSize("10px").setColor(new Color("#333")).setBackground(new Color("#FEB019"));
		chartOptions.getAnnotations().getYaxis().add(y);
		
		Xaxis x = new Xaxis();
		x.setX(new Date("23 Nov 2017").getTime())
			.setStrokeDashArray(0).setBorderColor(new Color("#775DD0"))
			.getLabel().setBorderColor(new Color("#775DD0")).setText("Anno Test")
				.getStyle().setColor(new Color("#fff")).setBackground(new Color("#775DD0"));
		chartOptions.getAnnotations().getXaxis().add(x);

		x = new Xaxis();
		x.setX(new Date("26 Nov 2017").getTime()).setX2(new Date("28 Nov 2017").getTime())
			.setFillColor(new Color("#B3F7CA")).setOpacity(0.4)
			.getLabel().setBorderColor(new Color("#B3F7CA")).setText("X-axis range").setOffsetY(-10)
				.getStyle().setFontSize("10px").setColor(new Color("#fff")).setBackground(new Color("#00E396"));
		chartOptions.getAnnotations().getXaxis().add(x);

		Points p = new Points();
		p.setX(new Date("01 Dec 2017").getTime()).setY(8607.55)
			.getMarker().setSize(8).setFillColor(new Color("#fff"))
				.setStrokeColor(new Color("red"))
				.setRadius(2).setCssClass("apexcharts-custom-class");
		p.getLabel().setBorderColor(new Color("#FF4560")).setText("Point Annotation").setOffsetY(0)
			.getStyle().setColor(new Color("#fff")).setBackground(new Color("#FF4560"));
		chartOptions.getAnnotations().getPoints().add(p);
		
		p = new Points();
		p.setX(new Date("08 Dec 2017").getTime()).setY(9340.85)
			.getMarker().setSize(0);
		p.getImage().setPath("https://hyjavacharts.com/content/images/ico-instagram.png");
		chartOptions.getAnnotations().getPoints().add(p);
		
		chartOptions.getDataLabels().setEnabled(false);
		chartOptions.getStroke().setCurve(Curve.STRAIGHT);
		
		chartOptions.getTitle().setText("Line with Annotations").setAlign((HorizontalAlign.LEFT));
		chartOptions.getGrid().getPadding().setRight(30).setLeft(20);
		
		chartOptions.setLabels(getSeriesDates());
		
		chartOptions.getXaxis().setType(AxisType.DATETIME);
		
		Series series = new Series();
		series.setData(getSeriesPricesJson());
		chartOptions.getSeries().add(series);
		
		return apexchart;
	}
	
	/**
	 * 
	 * @return
	 */
	private List<String> getSeriesDates() {
		return Arrays.asList(
				"13 Nov 2017", "14 Nov 2017", "15 Nov 2017", "16 Nov 2017", "17 Nov 2017", 
				"20 Nov 2017", "21 Nov 2017", "22 Nov 2017", "23 Nov 2017", "24 Nov 2017", 
				"27 Nov 2017", "28 Nov 2017", "29 Nov 2017", "30 Nov 2017", "01 Dec 2017", 
				"04 Dec 2017", "05 Dec 2017", "06 Dec 2017", "07 Dec 2017", "08 Dec 2017");
	}
	
	/**
	 * 
	 * @return
	 */
	private General getSeriesPricesJson() {
		return new General("[\r\n" + 
				"      8107.85,\r\n" + 
				"      8128.0,\r\n" + 
				"      8122.9,\r\n" + 
				"      8165.5,\r\n" + 
				"      8340.7,\r\n" + 
				"      8423.7,\r\n" + 
				"      8423.5,\r\n" + 
				"      8514.3,\r\n" + 
				"      8481.85,\r\n" + 
				"      8487.7,\r\n" + 
				"      8506.9,\r\n" + 
				"      8626.2,\r\n" + 
				"      8668.95,\r\n" + 
				"      8602.3,\r\n" + 
				"      8607.55,\r\n" + 
				"      8512.9,\r\n" + 
				"      8496.25,\r\n" + 
				"      8600.65,\r\n" + 
				"      8881.1,\r\n" + 
				"      9340.85\r\n" + 
				"    ]");
	}
	
}