package com.webonlineapp.hyjavachartsdemo10.examplecharts;

import java.util.Arrays;
import java.util.List;

import com.hyjavacharts.chart.Highchart;
import com.hyjavacharts.model.common.Color;
import com.hyjavacharts.model.highcharts.ChartOptions;
import com.hyjavacharts.model.highcharts.XAxis;
import com.hyjavacharts.model.highcharts.YAxis;
import com.hyjavacharts.model.highcharts.constants.ChartType;
import com.hyjavacharts.model.highcharts.constants.Cursor;
import com.hyjavacharts.model.highcharts.constants.DashStyle;
import com.hyjavacharts.model.highcharts.series.SeriesSpline;
import com.webonlineapp.hyjavachartsdemo10.charts.DemoChartBase;

public class AccessibleLine extends DemoChartBase {
	private static final long serialVersionUID = 1L;

	public Highchart configure() {
		Highchart highChart = new Highchart();
		ChartOptions chartOptions = highChart.getChartOptions();
		
		List<Color> colors = Arrays.asList(
			new Color("#265FB5"), new Color("#222"), new Color("#698F01"), new Color("#F4693E"), 
			new Color("#4C0684"), new Color("#0FA388"), new Color("#B7104A"), new Color("#AF9023"), 
			new Color("#1A704C"), new Color("#B02FDD"));
		
		chartOptions.getChart().setType(ChartType.SPLINE);
	    
		chartOptions.getTitle().setText("Most common desktop screen readers");
		chartOptions.getSubtitle().setText("Source: WebAIM. Click on points to visit official screen reader website");

		chartOptions.getLegend().setSymbolWidth(40);

		YAxis yAxi = new YAxis();
		yAxi.getTitle().setText("Percentage usage");
		yAxi.getAccessibility().setDescription("Percentage usage");
		chartOptions.getYAxis().add(yAxi);

		XAxis xAxi = new XAxis();
		xAxi.getTitle().setText("Time");
		xAxi.getAccessibility().setDescription("Time from January 2009 to July 2015");
		xAxi.setCategories(Arrays.asList("December 2010", "May 2012", "January 2014", "July 2015", "October 2017", "September 2019"));
		chartOptions.getXAxis().add(xAxi);

		chartOptions.getTooltip().setValueSuffix("%");
	
		chartOptions.getPlotOptions()
			.getSeries()
				.setCursor(Cursor.POINTER)
				.getPoint().getEvents().getClick().setFunctionBody("window.location.href = this.series.options.description;");
		
		SeriesSpline seriesSpline = new SeriesSpline();
		seriesSpline.setName("NVDA").setDescription("https://www.nvaccess.org").setColor(colors.get(2));
		seriesSpline.setDataAsArrayNumber(Arrays.asList(34.8, 43.0, 51.2, 41.4, 64.9, 72.4));
		chartOptions.getSeries().add(seriesSpline);
		
		seriesSpline = new SeriesSpline();
		seriesSpline.setName("JAWS").setDescription("https://www.freedomscientific.com/Products/Blindness/JAWS")
			.setDashStyle(DashStyle.SHORTDASHDOT).setColor(colors.get(0));
		seriesSpline.setDataAsArrayNumber(Arrays.asList(69.6, 63.7, 63.9, 43.7, 66.0, 61.7));
		chartOptions.getSeries().add(seriesSpline);

		seriesSpline = new SeriesSpline();
		seriesSpline.setName("VoiceOver").setDescription("http://www.apple.com/accessibility/osx/voiceover")
			.setDashStyle(DashStyle.SHORTDOT).setColor(colors.get(1));
		seriesSpline.setDataAsArrayNumber(Arrays.asList(20.2, 30.7, 36.8, 30.9, 39.6, 47.1));
		chartOptions.getSeries().add(seriesSpline);
		
		seriesSpline = new SeriesSpline();
		seriesSpline.setName("Narrator").setDescription("https://support.microsoft.com/en-us/help/22798/windows-10-complete-guide-to-narrator")
			.setDashStyle(DashStyle.DASH).setColor(colors.get(9));
		seriesSpline.setDataAsArrayNumber(Arrays.asList(null, null, null, null, 21.4, 30.3));
		chartOptions.getSeries().add(seriesSpline);
		
		seriesSpline = new SeriesSpline();
		seriesSpline.setName("ZoomText/Fusion").setDescription("http://www.zoomtext.com/products/zoomtext-magnifierreader")
			.setDashStyle(DashStyle.SHORTDOT).setColor(colors.get(5));
		seriesSpline.setDataAsArrayNumber(Arrays.asList(6.1, 6.8, 5.3, 27.5, 6.0, 5.5));
		chartOptions.getSeries().add(seriesSpline);

		seriesSpline = new SeriesSpline();
		seriesSpline.setName("Other").setDescription("http://www.disabled-world.com/assistivedevices/computer/screen-readers.php")
			.setDashStyle(DashStyle.SHORTDASH).setColor(colors.get(3));
		seriesSpline.setDataAsArrayNumber(Arrays.asList(42.6, 51.5, 54.2, 45.8, 20.2, 15.4));
		chartOptions.getSeries().add(seriesSpline);
		
		chartOptions.getResponsive().getRulesSingle().getCondition().setMaxWidth(550);
		chartOptions.getResponsive().getRulesSingle().getChartOptions().getChart()
													.setSpacingLeft(3).setSpacingRight(3);
		chartOptions.getResponsive().getRulesSingle().getChartOptions().getLegend().setItemWidth(150);
		chartOptions.getResponsive().getRulesSingle().getChartOptions().getXAxisSingle()
			.setCategories(Arrays.asList("Dec. 2010", "May 2012", "Jan. 2014", "July 2015", "Oct. 2017", "Sep. 2019"))
			.getTitle().setText("");
		chartOptions.getResponsive().getRulesSingle().getChartOptions().getYAxisSingle().setVisible(false);
		
		return highChart;
	}
	
	/**
	 * 
	 */
	public AccessibleLine() {
		setWidth("90%");
	}
}

