package com.webonlineapp.hyjavachartsdemo10.examplecharts;

import java.util.ArrayList;
import java.util.Calendar;

import com.hyjavacharts.chart.Highchart;
import com.hyjavacharts.model.common.Color;
import com.hyjavacharts.model.common.Function;
import com.hyjavacharts.model.highcharts.ChartOptions;
import com.hyjavacharts.model.highcharts.XAxis;
import com.hyjavacharts.model.highcharts.YAxis;
import com.hyjavacharts.model.highcharts.constants.AxisType;
import com.hyjavacharts.model.highcharts.constants.ChartType;
import com.hyjavacharts.model.highcharts.constants.SeriesType;
import com.hyjavacharts.model.highcharts.series.SeriesSpline;
import com.hyjavacharts.model.highcharts.series.seriesspline.Data;
import com.hyjavacharts.model.highcharts.yaxis.PlotLines;
import com.webonlineapp.hyjavachartsdemo10.charts.DemoChartBase;

public class DynamicSplineUpdating extends DemoChartBase {
	private static final long serialVersionUID = 1L;
	
	public Highchart configure() {
		Highchart highChart = new Highchart();
		ChartOptions chartOptions = highChart.getChartOptions();
		
		chartOptions.getTime().setUseUTC(false);
		
		chartOptions.getChart().setType(ChartType.SPLINE).setMarginRight(10).getEvents().setLoad(new Function(getLoadFunction()));
		chartOptions.getTitle().setText("Live random data");
		chartOptions.getXAxis().add(new XAxis().setType(AxisType.DATETIME).setTickPixelInterval(150));
		
		YAxis yAxi = new YAxis();
		yAxi.getTitle().setText("Value");
		yAxi.getPlotLines().add(new PlotLines().setValue(0f).setWidth(1).setColor(new Color("#808080")));
		chartOptions.getYAxis().add(yAxi);
		
		chartOptions.getTooltip().getFormatter()
			.setFunctionBody("return '<b>'+ this.series.name +'</b><br/>'+"
                    + "Highcharts.dateFormat('%Y-%m-%d %H:%M:%S', this.x) +'<br/>'+"
                    + "Highcharts.numberFormat(this.y, 2);");

		chartOptions.getLegend().setEnabled(true);
		chartOptions.getExporting().setEnabled(true);
		
		SeriesSpline seriesSpline = new SeriesSpline();
		seriesSpline.getLabel().setEnabled(false);
		seriesSpline.setType(SeriesType.SPLINE).setName("Random data");
		seriesSpline.setDataAsArrayObject(getSeriesData());
		chartOptions.getSeries().add(seriesSpline);
		
		return highChart;
	}

	/**
	 * 
	 * @return
	 */
	private ArrayList<Data> getSeriesData() {
		Calendar cal = Calendar.getInstance();

		ArrayList<Data> data = new ArrayList<Data>();
		long time = cal.getTime().getTime();
		int i;
		
		for (i = -19; i <= 0; i += 1) {
			data.add(new Data().setX(time + i * 1000).setY(Math.random()));
		}
		
		return data;
	}
	
	/**
	 * 
	 * @return
	 */
	private String getLoadFunction() {
		return "var series = this.series[0];" + 
				"intervalId = setInterval(function () {" + 
				"var x = (new Date()).getTime()," + 
				"y = Math.random();" + 
				"series.addPoint([x, y], true, true);" + 
			"}, 1000);";
	}

}
