package com.webonlineapp.hyjavachartsdemo10.examplecharts;

import java.util.Arrays;

import com.hyjavacharts.chart.Highchart;
import com.hyjavacharts.model.common.Color;
import com.hyjavacharts.model.common.Function;
import com.hyjavacharts.model.highcharts.ChartOptions;
import com.hyjavacharts.model.highcharts.constants.HorizontalAlign;
import com.hyjavacharts.model.highcharts.constants.SeriesType;
import com.hyjavacharts.model.highcharts.constants.VerticalAlign;
import com.hyjavacharts.model.highcharts.series.SeriesPie;
import com.hyjavacharts.model.highcharts.series.seriespie.Data;
import com.webonlineapp.hyjavachartsdemo10.charts.DemoChartBase;

public class DonutChartRace extends DemoChartBase {
	private static final long serialVersionUID = 1L;

	public Highchart configure() {
		Highchart highChart = new Highchart();
		ChartOptions chartOptions = highChart.getChartOptions();
	    
		chartOptions.getTitle()
			.setText("Nuclear energy production from 1965 to 2021 in US, UK, France, Germany, and Japan")
			.setAlign(HorizontalAlign.CENTER);
		
		chartOptions.getSubtitle()
			.setUseHTML(true)
			.setFloating(true)
			.setVerticalAlign(VerticalAlign.MIDDLE)
			.setY(30)
			.setText("<span style=\"font-size: 80px\">1965</span><br><span style=\"font-size: 22px\">Total: <b> 20.02</b> TWh</span>");
		
		chartOptions.getLegend().setEnabled(false);
		chartOptions.getTooltip().setValueDecimals(2).setValueSuffix("TWh");
		
		chartOptions.getPlotOptions()
			.getPie()
				.setBorderWidth(0)
				.setSize("100%")
				.setInnerSize("80%")
				.getDataLabels()
					.setEnabled(true).setCrop(false).setDistance("-10%").setConnectorWidth(0)
					.getStyle().setFontWeight("bold").setFontSize("16px");

		chartOptions.setColors(Arrays.asList(
			new Color("#FCE700"), new Color("#F8C4B4"), new Color("#f6e1ea"), 
			new Color("#B8E8FC"), new Color("#BCE29E")));

		SeriesPie seriesPie = new SeriesPie();
		seriesPie.setType(SeriesType.PIE).setName("1965");
		
		seriesPie.setDataAsArrayObject(Arrays.asList(
				new Data().setName("DE").setY(0.117),
				new Data().setName("FR").setY(0.897),
				new Data().setName("UK").setY(15.135),
				new Data().setName("JP").setY(0.025),
				new Data().setName("US").setY(3.8491569)
				));
		chartOptions.getSeries().add(seriesPie);
		
		chartOptions.getChart().getEvents().setLoad(new Function(getLoadFunction()));
		
		return highChart;
	}
	
	/**
     * 
     * @return
     */
    private String getLoadFunction() {
        return 
        	"\r\n" + 
        	"var year = 1966;\r\n" + 
        	"var dataset;\r\n" + 
	 		
	        "const xhttp = new XMLHttpRequest();\r\n" + 
	        "xhttp.onload = function() {\r\n" + 
	        "    dataset = JSON.parse(this.responseText);\r\n" + 
	        "} \r\n" + 
	        "xhttp.open('GET', 'https://www.hyjavacharts.com/app/HyJavaChartsServices/NuclearEnergy', false);\r\n" + 
	        "xhttp.send(); \r\n" + 
	        
	        "intervalId = setInterval(function () {\r\n" + 
	        "    const output = Object.entries(dataset).map(country => {\r\n" + 
	        "        const [countryName, countryData] = country;\r\n" + 
	        "        return [countryName, Number(countryData[year])];\r\n" + 
	        "    });\r\n" + 
	        
	        "    var energydata = [output[0], output.slice(0, 6)][1];\r\n" + 
	        "    var energytotal = energydata[0][1].toFixed(2);\r\n" + 
	        
	        "    chart.update({\r\n" +
	        "        subtitle: { text: " + "`<span style=\"font-size: 80px\">" + "${year}" + "</span><br><span style=\"font-size: 22px\">Total: <b> ${energytotal}</b> TWh</span>`" + " }\r\n" +
	        "      }, false, false, false\r\n" + 
	        "    );\r\n" + 
	        
	        "    chart.series[0].update({\r\n" + 
	        "        name: year.toString(),\r\n" + 
	        "        data: energydata.slice(1,6)\r\n" + 
	        "    });\r\n" + 
	
	        "    year++;\r\n" +
			"    if (year > 2021) {\r\n" +
			"        clearInterval(intervalId);\r\n" +
			"    }\r\n"  +
	        "}, 1000);\r\n"
			;
    }

}
