package com.webonlineapp.hyjavachartsdemo10.examplecharts;

import java.util.Arrays;
import java.util.List;

import com.hyjavacharts.chart.Highchart;
import com.hyjavacharts.model.common.Color;
import com.hyjavacharts.model.highcharts.ChartOptions;
import com.hyjavacharts.model.highcharts.XAxis;
import com.hyjavacharts.model.highcharts.constants.ChartType;
import com.hyjavacharts.model.highcharts.constants.DashStyle;
import com.hyjavacharts.model.highcharts.series.SeriesArea;
import com.hyjavacharts.model.highcharts.series.seriesarea.Data;
import com.webonlineapp.hyjavachartsdemo10.charts.DemoChartBase;

public class ThreeDArea extends DemoChartBase {
	private static final long serialVersionUID = 1L;

	public Highchart configure() {
		Highchart highChart = new Highchart();
		ChartOptions chartOptions = highChart.getChartOptions();
		
		chartOptions.getChart().setType(ChartType.AREA);
		chartOptions.getChart().getOptions3d().setEnabled(true).setAlpha(15).setBeta(30).setDepth(200);
		
		chartOptions.getTitle().setText("Visual comparison of Mountains Panorama");

		chartOptions.getYAxisSingle().getTitle().setText("Height Above Sea Level").setX(-40);
		chartOptions.getYAxisSingle().setGridLineDashStyle(DashStyle.DASH)
			.getLabels().setFormat("{value:,.0f} MAMSL");
		
		chartOptions.getXAxis().add(new XAxis().setVisible(false));
		chartOptions.getXAxis().add(new XAxis().setVisible(false));
		chartOptions.getXAxis().add(new XAxis().setVisible(false));
		
		chartOptions.getPlotOptions().getArea().setDepth(100).getMarker().setEnabled(false);
		chartOptions.getPlotOptions().getArea().getStates().getInactive().setEnabled(false);
		
		chartOptions.getTooltip().setValueSuffix(" MAMSL");
		
		SeriesArea seriesArea = new SeriesArea();
		seriesArea.getLabel().setEnabled(false);
		seriesArea.setName("Tatra Mountains visible from Rusinowa polana")
					.setLineColor(new Color(180,90,50))
					.setColor(new Color(200,110,50))
					.setFillColor(new Color(200,110,50));
		seriesArea.setDataAsArrayObject(getData(0));
		chartOptions.getSeries().add(seriesArea);
		
		seriesArea = new SeriesArea();
		seriesArea.getLabel().setEnabled(false);
		seriesArea.setName("Dachstein panorama seen from Krippenstein")
					.setLineColor(new Color(120,160,180))
					.setColor(new Color(140,180,200))
					.setFillColor(new Color(140,180,200))
					.setXAxis(1);
		seriesArea.setDataAsArrayObject(getData(1));
		chartOptions.getSeries().add(seriesArea);

		seriesArea = new SeriesArea();
		seriesArea.getLabel().setEnabled(false);
		seriesArea.setName("Panorama from Col Des Mines")
					.setLineColor(new Color(200, 190, 140))
					.setColor(new Color(200, 190, 140))
					.setFillColor(new Color(230, 220, 180))
					.setXAxis(2);
		seriesArea.setDataAsArrayObject(getData(2));
		chartOptions.getSeries().add(seriesArea);
		
		return highChart;
	}
	
	/**
	 * 
	 * @param id
	 * @return
	 */
	private List<Data> getData(int id) {
		if (id == 0) {
			return Arrays.asList(
					new Data().setName("Murań").setY(1890),
					new Data().setName("Nowy Wierch").setY(2009),
					new Data().setName("Hawrań").setY(2152),
					new Data().setName("Płaczliwa Skała").setY(2142),
					new Data().setName("Szalony Wierch").setY(2061),
					new Data().setName("Karczmarski Wierch").setY(1438),
					new Data().setName("Jagnięcy Szczyt").setY(2230),
					new Data().setName("Czerwona Turnia").setY(2284),
					new Data().setName("Kołowy Szczyt").setY(2418),
					new Data().setName("Czarny Szczyt").setY(2429),
					new Data().setName("Baranie Rogi").setY(2526),
					new Data().setName("Śnieżny Szczyt").setY(2465),
					new Data().setName("Lodowy Szczyt").setY(2627),
					new Data().setName("Lodowa Kopa").setY(2602),
					new Data().setName("Szeroka Jaworzyńska").setY(2210),
					new Data().setName("Horwacki Wierch").setY(1902),
					new Data().setName("Spismichałowa Czuba").setY(2012),
					new Data().setName("Zielona Czuba").setY(2130),
					new Data().setName("Wielicki Szczyt").setY(2318),
					new Data().setName("Gerlach").setY(2655),
					new Data().setName("Batyżowiecki Szczyt").setY(2448),
					new Data().setName("Kaczy Szczyt").setY(2395),
					new Data().setName("Zmarzły Szczyt").setY(2390),
					new Data().setName("Kończysta").setY(2538),
					new Data().setName("Młynarz").setY(2170),
					new Data().setName("Ganek").setY(2462),
					new Data().setName("Wysoka").setY(2547),
					new Data().setName("Ciężki Szczyt").setY(2520),
					new Data().setName("Rysy").setY(2503),
					new Data().setName("Żabi Mnich").setY(2146),
					new Data().setName("Żabi Koń").setY(2291),
					new Data().setName("Żabia Turnia Mięguszowiecka").setY(2335),
					new Data().setName("Wołowa Turnia").setY(2373));
		}
		else if (id == 1) {
			return Arrays.asList(
					new Data().setName("Kufstein").setY(2049),
					new Data().setName("Hohe Wildstelle").setY(2746),
					new Data().setName("Kleiner Miesberg").setY(2173),
					new Data().setName("Großer Miesberg").setY(2202),
					new Data().setName("Hochstein").setY(2543),
					new Data().setName("Lackner Miesberg").setY(2232),
					new Data().setName("Wasenspitze").setY(2257),
					new Data().setName("Sinabell").setY(2349),
					new Data().setName("Feister Scharte").setY(2198),
					new Data().setName("Eselstein").setY(2556),
					new Data().setName("Landfriedstein").setY(2536),
					new Data().setName("Scheichenspitz").setY(2667),
					new Data().setName("Schmiedstock").setY(2634),
					new Data().setName("Gamsfeldspitze").setY(2611),
					new Data().setName("Edelgriess").setY(2305),
					new Data().setName("Koppenkarstein").setY(2863),
					new Data().setName("Niederer Gjaidstein").setY(2483),
					new Data().setName("Hoher Gjaidstein").setY(2794),
					new Data().setName("Hoher Dachstein").setY(2995),
					new Data().setName("Niederer Dachstein").setY(2934),
					new Data().setName("Hohes Kreuz").setY(2837),
					new Data().setName("Hoher Ochsenkogel").setY(2513));
		}
		else {
			return Arrays.asList(
					new Data().setName("Combin de la Tsessette").setY(4141),
					new Data().setName("Grand Combin de Grafeneire").setY(4314),
					new Data().setName("Combin de Corbassière").setY(3716),
					new Data().setName("Petit Combin").setY(3672),
					new Data().setName("Pointe de Boveire").setY(3212),
					new Data().setName("Grand Aget").setY(3133),
					new Data().setName("Mont Rogneux").setY(3084),
					new Data().setName("Dents du Grand Lé").setY(2884),
					new Data().setName("Monts Telliers").setY(2951),
					new Data().setName("Grand Golliat").setY(3238),
					new Data().setName("Mont Grande Rochère").setY(3326),
					new Data().setName("Mont de la Fouly").setY(2871),
					new Data().setName("Tête de la Payanne").setY(2452),
					new Data().setName("Pointe Allobrogia").setY(3172),
					new Data().setName("Six Blanc").setY(2334),
					new Data().setName("Mont Dolent").setY(3820),
					new Data().setName("Aiguille de Triolet").setY(3870),
					new Data().setName("Le Tour Noir").setY(3836),
					new Data().setName("Aiguille de l'A Neuve").setY(3753),
					new Data().setName("Aiguille d'Argentière").setY(3900),
					new Data().setName("Aiguille du Chardonnet").setY(3824),
					new Data().setName("Aiguille du Tour").setY(3540),
					new Data().setName("Aiguille du Pissoir").setY(3440),
					new Data().setName("Le Catogne").setY(2598),
					new Data().setName("Pointe de Prosom").setY(2762),
					new Data().setName("Pointe Ronde").setY(2700),
					new Data().setName("Mont Buet").setY(3096),
					new Data().setName("Le Cheval Blanc").setY(2831),
					new Data().setName("Pointe de la Finive").setY(2838),
					new Data().setName("Pic de Tenneverge").setY(2985),
					new Data().setName("Pointe d'Aboillon").setY(2819),
					new Data().setName("Tour Sallière").setY(3220),
					new Data().setName("Le Dôme").setY(3138),
					new Data().setName("Haute Cime").setY(3257),
					new Data().setName("Pierre Avoi").setY(2473),
					new Data().setName("Cime de l'Est").setY(3178));
		}
	}

}