package com.webonlineapp;

import com.vaadin.flow.component.Component;
import com.vaadin.flow.component.HasComponents;
import com.vaadin.flow.component.HasSize;
import com.vaadin.flow.component.Tag;
import com.vaadin.flow.component.UI;
import com.vaadin.flow.component.dependency.JavaScript;
import com.vaadin.flow.component.page.Page;

@Tag("div")
@JavaScript("https://code.highcharts.com/stock/10.3.3/highstock.js")
@JavaScript("https://code.highcharts.com/10.3.3/modules/exporting.js")
@JavaScript("https://cdn.jsdelivr.net/npm/apexcharts@3.39.0")

public class ChartComponent extends Component implements HasComponents, HasSize {
	private static final long serialVersionUID = 806054527112127036L;
	
	private static long chartId = 1;
	private String chartType = "highcharts";
	
	
	/**
	 * 
	 */
	public ChartComponent() { 
        setId("thechart_" + getNextChartId());
 	}
	
	/**
	 * 
	 * @param chartType
	 */
	public void setChartType(String chartType) {
		this.chartType = chartType;
	}
	
	/**
	 * 
	 * @param chartOptions
	 */
	public void displayChart(String chartOptions) {
		displayChart("", chartOptions);
	}
	
	/**
	 * 
	 * @param globalOptions
	 * @param chartOptions
	 */
	public void displayChart(String globalOptions, String chartOptions) {
		Page page = UI.getCurrent().getPage();
		
		if (chartType.equals("apexchart")) {
			String chartOptionsJs = "var chart = new ApexCharts(document.querySelector('#" 
					+ getId().get() + "'), " + chartOptions + ");chart.render();";
			page.executeJs(chartOptionsJs);
		}
		else {
			if (globalOptions != null && !globalOptions.equals("")) {
				String globalOptionsJs = "Highcharts.setOptions(" + globalOptions + ");";
				page.executeJs(globalOptionsJs);
			}
	
	    	String chartOptionsJs = (chartType.equals("highcharts") ? "Highcharts.chart('" : "Highcharts.stockChart('") 
	    				+ getId().get() + "', " + chartOptions + ");";
	    	page.executeJs(chartOptionsJs);
		}
	}
	
	/**
	 * 
	 * @return
	 */
	private long getNextChartId() {
		chartId++;
		
		if (chartId > 10000) {
			chartId = 1;
		}
		
		return chartId;
	}
	
}
