package com.webonlineapp.hyjavastockdemo10.examplecharts;

import com.hyjavastock.chart.Highstock;
import com.hyjavastock.model.common.Color;
import com.hyjavastock.model.highstock.ChartOptions;
import com.hyjavastock.model.highstock.YAxis;
import com.hyjavastock.model.highstock.constants.ChartType;
import com.hyjavastock.model.highstock.constants.HorizontalAlign;
import com.hyjavastock.model.highstock.constants.Step;
import com.hyjavastock.model.highstock.constants.TickPosition;
import com.hyjavastock.model.highstock.constants.ZoomType;
import com.hyjavastock.model.highstock.series.SeriesArea;
import com.webonlineapp.hyjavastockdemo10.chartdata.DepthData;
import com.webonlineapp.hyjavastockdemo10.charts.DemoChartBase;

public class DepthChart extends DemoChartBase {
	private static final long serialVersionUID = 1L;

	public Highstock configure() {
		Highstock highStock = new Highstock();
		ChartOptions chartOptions = highStock.getChartOptions();
		
		chartOptions.getStockTools().getGui().setEnabled(false);
		chartOptions.getNavigator().setEnabled(false);
		chartOptions.getScrollbar().setEnabled(false);
		chartOptions.getRangeSelector().setEnabled(false);
	    
		chartOptions.getChart().setType(ChartType.AREA)
			.getZooming().setType(ZoomType.XY);
		
		chartOptions.getTitle().setText("ETH-BTC Market Depth");
		
		chartOptions.getXAxisSingle().setMinPadding(0).setMaxPadding(0).getTitle().setText("Price");
		chartOptions.getXAxisSingle().getPlotLinesSingle()
			.setColor(new Color("#888")).setValue(0.1523).setWidth(1)
				.getLabel().setText("Actual price").setRotation(90);
		
		YAxis yAxis = new YAxis();
		yAxis.setLineWidth(1).setGridLineWidth(1).setTitle(null)
			.setTickWidth(1).setTickLength(5).setTickPosition(TickPosition.INSIDE)
				.getLabels().setAlign(HorizontalAlign.LEFT).setX(8);
		chartOptions.getYAxis().add(yAxis);
		
		yAxis = new YAxis();
		yAxis.setOpposite(true).setLinkedTo(0).setLineWidth(1).setGridLineWidth(0).setTitle(null)
			.setTickWidth(1).setTickLength(5).setTickPosition(TickPosition.INSIDE)
				.getLabels().setAlign(HorizontalAlign.RIGHT).setX(-8);
		chartOptions.getYAxis().add(yAxis);
		
		chartOptions.getLegend().setEnabled(false);
		
		chartOptions.getPlotOptions().getArea().setFillOpacity(0.2).setLineWidth(1).setStep(Step.CENTER);
		
		chartOptions.getTooltip()
			.setHeaderFormat("<span style='font-size=10px;'>Price: {point.key}</span><br/>")
			.setValueDecimals(2);
		
		SeriesArea seriesArea = new SeriesArea();
		seriesArea.setName("Bids").setColor(new Color("#03a7a8"));
		seriesArea.getDataAsJsValue().setJsValue(new DepthData().getBids());
		chartOptions.getSeries().add(seriesArea);
		
		seriesArea = new SeriesArea();
		seriesArea.setName("Asks").setColor(new Color("#fc5857"));
		seriesArea.getDataAsJsValue().setJsValue(new DepthData().getAsks());
		chartOptions.getSeries().add(seriesArea);
		
		this.setHighcharts(true);
		
		return highStock;
	}
	
}