package com.webonlineapp;

import java.io.IOException;

import javax.servlet.ServletException;
import javax.servlet.http.HttpServlet;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import com.webonlineapp.charts.ApexChartsBasicColumn;
import com.webonlineapp.charts.HighchartsLine;
import com.webonlineapp.charts.HighchartsPie;
import com.webonlineapp.charts.HighstockColumn;
import com.webonlineapp.content.ApexChartContent;
import com.webonlineapp.content.HighchartContent;
import com.webonlineapp.content.HighchartStockContent;
import com.webonlineapp.content.PageContent;

/*
 * A very primitive and simple proof of concept example to show how to integrate 
 *   Highcharts and the HyJavaCharts library
 * plus
 *   Highcharts Stock and the HyJavaStock library
 * plus
 *   ApexCharts and the HyJavaApex library 
 *   
 * in a web application.
 * 
 * The Charts available are: 
 *   Highcharts line and pie charts
 *   Highcharts Stock column chart
 *   ApexCharts basic column chart
 *   
 */
public class HyJavaChartsSimpleDemo extends HttpServlet {
	private static final long serialVersionUID = 1L;
	

	/**
	 * 
	 */
	public HyJavaChartsSimpleDemo() {
		super();
	}

	/**
	 * 
	 */
	protected void doGet(HttpServletRequest request, HttpServletResponse response)
			throws ServletException, IOException {
		String requestedChart = request.getParameter("chartName") == null ? "line" : request.getParameter("chartName"); // defaults to line

		response.setContentType("text/html");
		response.getWriter().println(new PageContent().build(requestedChart, getChartContent(requestedChart)));
	}
	
	/**
	 * 
	 * @param requestedChart
	 * @return
	 */
	private String getChartContent(String requestedChart) {
		if (requestedChart.equals("stock")) {
			return new HighchartStockContent().build(new HighstockColumn().configure());
		}
		else if (requestedChart.equals("apex")) {
			return new ApexChartContent().build(new ApexChartsBasicColumn().configure());
		}
		else if (requestedChart.equals("line")) {
			return new HighchartContent().build(new HighchartsLine().configure());
		}
		else {
			return new HighchartContent().build(new HighchartsPie().configure());
		}
	}

	/**
	 * 
	 */
	protected void doPost(HttpServletRequest request, HttpServletResponse response)
			throws ServletException, IOException {
		doGet(request, response);
	}

}
