package com.webonlineapp;
	
import com.webonlineapp.charts.ApexChartsBasicColumn;
import com.webonlineapp.charts.HighchartsLine;
import com.webonlineapp.charts.HighchartsPie;
import com.webonlineapp.charts.HighstockColumn;
import com.webonlineapp.content.ApexChartContent;
import com.webonlineapp.content.HighchartContent;
import com.webonlineapp.content.HighchartStockContent;

import javafx.application.Application;
import javafx.event.ActionEvent;
import javafx.event.EventHandler;
import javafx.geometry.Insets;
import javafx.scene.Scene;
import javafx.scene.control.Button;
import javafx.scene.layout.BorderPane;
import javafx.scene.layout.HBox;
import javafx.scene.layout.VBox;
import javafx.scene.web.WebEngine;
import javafx.scene.web.WebView;
import javafx.stage.Stage;

/*
 * A simple proof of concept example application to show how to integrate
 *   Highcharts and the HyJavaCharts library
 * plus
 *   Highcharts Stock and the HyJavaStock library
 * plus
 *   ApexCharts and the HyJavaApex library
 *   
 * in a JavaFX application.
 * 
 * NOTE: We are not experts in JavaFx so there will no doubt be better ways to accomplish the same thing.
 * 
 */
public class Main extends Application {

    @Override
    public void start(Stage primaryStage) {
    	primaryStage.setTitle("HyJavaCharts, HyJavaStock and HyJavaApex JavaFX Demo");
    	VBox root = new VBox();
    	
        WebView webView = new WebView();
        WebEngine engine = webView.getEngine();

        HBox buttons = new HBox();
        buttons.setSpacing(10);
        buttons.setPadding(new Insets(15, 12, 15, 12));
        
        Button lineChartButton = new Button("Highcharts Line Chart");
        buttons.getChildren().add(lineChartButton);
        
        Button pieChartButton = new Button("Highcharts Pie Chart");
        buttons.getChildren().add(pieChartButton);
        
        Button stockChartButton = new Button("Highstock Column Chart");
        buttons.getChildren().add(stockChartButton);
        
        Button apexChartButton = new Button("ApexCharts Column Chart");
        buttons.getChildren().add(apexChartButton);
        
        root.getChildren().add(buttons);
        root.getChildren().add(webView);
        
        lineChartButton.setOnAction(new EventHandler<ActionEvent>() {
            @Override public void handle(ActionEvent e) {
            	engine.loadContent(new HighchartContent().build(new HighchartsLine().configure()));
            }
        });
        
        pieChartButton.setOnAction(new EventHandler<ActionEvent>() {
            @Override public void handle(ActionEvent e) {
            	engine.loadContent(new HighchartContent().build(new HighchartsPie().configure()));
            }
        });
        
        stockChartButton.setOnAction(new EventHandler<ActionEvent>() {
            @Override public void handle(ActionEvent e) {
            	engine.loadContent(new HighchartStockContent().build(new HighstockColumn().configure()));
            }
        });
        
        apexChartButton.setOnAction(new EventHandler<ActionEvent>() {
            @Override public void handle(ActionEvent e) {
            	engine.loadContent(new ApexChartContent().build(new ApexChartsBasicColumn().configure()));
            }
        });

        primaryStage.setScene(new Scene(new BorderPane(root)));
        primaryStage.show();
    }
    
    /**
     * 
     * @param args
     */
	public static void main(String[] args) {
		launch(args);
	}
}
