package com.webonlineapp;

import java.awt.Dimension;
import java.awt.FlowLayout;
import java.awt.event.WindowAdapter;
import java.awt.event.WindowEvent;
import java.io.IOException;

import javax.swing.BoxLayout;
import javax.swing.JButton;
import javax.swing.JFrame;
import javax.swing.JLabel;
import javax.swing.JPanel;
import javax.swing.SwingUtilities;
import javax.swing.UIManager;

import org.cef.CefApp;
import org.cef.CefApp.CefAppState;
import org.cef.CefClient;
import org.cef.browser.CefBrowser;
import org.cef.browser.CefMessageRouter;

import com.webonlineapp.charts.ApexChartsBasicColumn;
import com.webonlineapp.charts.HighchartsLine;
import com.webonlineapp.charts.HighchartsPie;
import com.webonlineapp.charts.HighstockColumn;
import com.webonlineapp.content.ApexChartContent;
import com.webonlineapp.content.HighchartContent;
import com.webonlineapp.content.HighchartStockContent;

import me.friwi.jcefmaven.CefAppBuilder;
import me.friwi.jcefmaven.CefInitializationException;
import me.friwi.jcefmaven.MavenCefAppHandlerAdapter;
import me.friwi.jcefmaven.UnsupportedPlatformException;

/*
 * A simple proof of concept example application to show how to integrate
 *   Highcharts and the HyJavaCharts library
 * plus
 *   Highcharts Stock and the HyJavaStock library
 * plus
 *   ApexCharts and the HyJavaApex library
 *   
 * in a Java Swing application using JCEF.
 * 
 * The first run of this application will download the required JCEF (Java Chromium Embedded Framework) 
 * libraries (approx 100mb).
 * See https://github.com/chromiumembedded/java-cef and https://github.com/jcefmaven/jcefmaven
 * 
 * NOTE: We are not experts in Swing so there will no doubt be better ways to accomplish the same thing.
 * 
 */
public class JCEFDemoMain {
	CefBrowser browser = initialiseBrowser();

	/**
	 * 
	 */
	public JCEFDemoMain() {
		JFrame frame = new JFrame();
		frame.setTitle("HyJavaCharts, HyJavaStock and HyJavaApex Swing Demo (using JCEF)");
		frame.setDefaultCloseOperation(JFrame.EXIT_ON_CLOSE);
		frame.setResizable(true);
		frame.setVisible(true);
		frame.pack();
		frame.setSize(new Dimension(850, 650));
		frame.setLocationRelativeTo(null);

		JPanel main = new JPanel();
		BoxLayout boxlayout = new BoxLayout(main, BoxLayout.Y_AXIS);
		main.setLayout(boxlayout);

		JPanel buttons = new JPanel(new FlowLayout(FlowLayout.LEFT, 8, 8));
		JButton lineChartButton = new JButton("Highcharts Line Chart");
		buttons.add(lineChartButton);

		JButton pieChartButton = new JButton("Highcharts Pie Chart");
		buttons.add(pieChartButton);

		JButton stockChartButton = new JButton("Highstock Column Chart");
		buttons.add(stockChartButton);
		
		JButton apexChartButton = new JButton("ApexCharts Column Chart");
		buttons.add(apexChartButton);
		
		JLabel version = new JLabel("  Chrome Version: " + CefApp.getInstance().getVersion().getChromeVersion());
		buttons.add(version);

		main.add(buttons);
		main.add(browser.getUIComponent());

		frame.add(main);

		// line chart button
		lineChartButton.addActionListener((e) -> {
			browser.loadURL(new HighchartContent(true).build(new HighchartsLine().configure()));
		});

		// pie chart button
		pieChartButton.addActionListener((e) -> {
			browser.loadURL(new HighchartContent(true).build(new HighchartsPie().configure()));
		});

		// stock chart button
		stockChartButton.addActionListener((e) -> {
			browser.loadURL(new HighchartStockContent(true).build(new HighstockColumn().configure()));
		});
		
		// apex chart button
		apexChartButton.addActionListener((e) -> {
			browser.loadURL(new ApexChartContent(true).build(new ApexChartsBasicColumn().configure()));
		});
		
		frame.addWindowListener(new WindowAdapter() {
	         @Override
	         public void windowClosing(WindowEvent e) {
	             CefApp.getInstance().dispose();
	             frame.dispose();
	         }
	     });
	}
	
	/**
	 * 
	 * @return
	 */
	private CefBrowser initialiseBrowser() {
		CefAppBuilder builder = new CefAppBuilder();
        builder.getCefSettings().windowless_rendering_enabled = false;
        
        builder.setAppHandler(new MavenCefAppHandlerAdapter() {
            @Override
            public void stateHasChanged(org.cef.CefApp.CefAppState state) {
                // Shutdown the app if the native CEF part is terminated
                if (state == CefAppState.TERMINATED) System.exit(0);
            }
        });
        
        CefApp cefApp = null;
        try {
        	cefApp = builder.build();
		} catch (IOException | UnsupportedPlatformException | InterruptedException | CefInitializationException e) {
			e.printStackTrace();
		}

        CefClient client = cefApp.createClient();
        
        CefMessageRouter msgRouter = CefMessageRouter.create();
        client.addMessageRouter(msgRouter);
        
        CefBrowser browser = client.createBrowser(null, false, false);
        //browser.createImmediately();
        
        return browser;
	}

	/**
	 * 
	 * @param args
	 */
	public static void main(String[] args) {
		try {
			UIManager.setLookAndFeel(UIManager.getSystemLookAndFeelClassName());
		} catch (Exception e) {
			e.printStackTrace();
		}

		SwingUtilities.invokeLater(() -> {
			new JCEFDemoMain();
		});
	}

}
