package com.webonlineapp;

import java.awt.Dimension;
import java.awt.FlowLayout;

import javax.swing.BoxLayout;
import javax.swing.JButton;
import javax.swing.JFrame;
import javax.swing.JPanel;
import javax.swing.SwingUtilities;
import javax.swing.UIManager;

import com.webonlineapp.charts.ApexChartsBasicColumn;
import com.webonlineapp.charts.HighchartsLine;
import com.webonlineapp.charts.HighchartsPie;
import com.webonlineapp.charts.HighstockColumn;
import com.webonlineapp.content.ApexChartContent;
import com.webonlineapp.content.HighchartContent;
import com.webonlineapp.content.HighchartStockContent;

import javafx.application.Platform;
import javafx.embed.swing.JFXPanel;
import javafx.scene.Group;
import javafx.scene.Scene;
import javafx.scene.web.WebEngine;
import javafx.scene.web.WebView;

/*
 * A simple proof of concept example application to show how to integrate
 *   Highcharts and the HyJavaCharts library
 * plus
 *   Highcharts Stock and the HyJavaStock library
 * plus
 *   ApexCharts and the HyJavaApex library
 *   
 * in a Java Swing application.
 * 
 * NOTE: We are not experts in Swing/JavaFX so there will no doubt be better ways to accomplish the same thing.
 * 
 */
public class WebViewDemoMain {
	private WebView webView;
	private WebEngine engine;

	/**
	 * 
	 */
	public WebViewDemoMain() {
		JFrame frame = new JFrame();
		frame.setTitle("HyJavaCharts, HyJavaStock and HyJavaApex Swing Demo (using WebView)");
		frame.setSize(new Dimension(850, 650));
		frame.setDefaultCloseOperation(JFrame.EXIT_ON_CLOSE);
		frame.setLocationRelativeTo(null);
		frame.setResizable(false);
		frame.setVisible(true);

		JPanel main = new JPanel();
		BoxLayout boxlayout = new BoxLayout(main, BoxLayout.Y_AXIS);
		main.setLayout(boxlayout);

		JPanel buttons = new JPanel(new FlowLayout(FlowLayout.LEFT, 8, 8));
		JButton lineChartButton = new JButton("Highcharts Line Chart");
		buttons.add(lineChartButton);

		JButton pieChartButton = new JButton("Highcharts Pie Chart");
		buttons.add(pieChartButton);

		JButton stockChartButton = new JButton("Highstock Column Chart");
		buttons.add(stockChartButton);
		
		JButton apexChartButton = new JButton("ApexCharts Column Chart");
		buttons.add(apexChartButton);

		main.add(buttons);

		JFXPanel fxPanel = new JFXPanel();
		main.add(fxPanel);

		frame.add(main);

		// line chart button
		lineChartButton.addActionListener((e) -> {
			Platform.runLater(new Runnable() {
				@Override
				public void run() {
					engine.loadContent(new HighchartContent().build(new HighchartsLine().configure()));
				}
			});
		});

		// pie chart button
		pieChartButton.addActionListener((e) -> {
			Platform.runLater(new Runnable() {
				@Override
				public void run() {
					engine.loadContent(new HighchartContent().build(new HighchartsPie().configure()));
				}
			});
		});

		// stock chart button
		stockChartButton.addActionListener((e) -> {
			Platform.runLater(new Runnable() {
				@Override
				public void run() {
					engine.loadContent(new HighchartStockContent().build(new HighstockColumn().configure()));
				}
			});
		});
		
		// apex chart button
		apexChartButton.addActionListener((e) -> {
			Platform.runLater(new Runnable() {
				@Override
				public void run() {
					engine.loadContent(new ApexChartContent().build(new ApexChartsBasicColumn().configure()));
				}
			});
		});

		Platform.runLater(new Runnable() {
			@Override
			public void run() {
				webView = new WebView();
				engine = webView.getEngine();

				initFX(fxPanel);
			}
		});
	}

	/**
	 * 
	 * @param fxPanel
	 */
	private void initFX(JFXPanel fxPanel) {
		// This method is invoked on the JavaFX thread
		Scene scene = createScene();
		fxPanel.setScene(scene);
	}

	/**
	 * 
	 * @return
	 */
	private Scene createScene() {
		Group root = new Group();
		Scene scene = new Scene(root);

		root.getChildren().add(webView);

		return scene;
	}

	/**
	 * 
	 * @param args
	 */
	public static void main(String[] args) {
		try {
			UIManager.setLookAndFeel(UIManager.getSystemLookAndFeelClassName());
		} catch (Exception e) {
			e.printStackTrace();
		}

		SwingUtilities.invokeLater(() -> {
			new WebViewDemoMain();
		});
	}

}
